OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendário",
    "To-dos" : "Tarefas",
    "Personal" : "Pessoal",
    "{actor} created calendar {calendar}" : "{actor} criou o calendário {calendar}",
    "You created calendar {calendar}" : "Você criou o calendário {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} excluiu o calendário {calendar}",
    "You deleted calendar {calendar}" : "Você excluiu o calendário {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} atualizou o calendário {calendar}",
    "You updated calendar {calendar}" : "Você atualizou o calendário {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} restaurou o calendário {calendar}",
    "You restored calendar {calendar}" : "Você restaurou o calendário {calendar}",
    "You shared calendar {calendar} as public link" : "Você compartilhou o calendário {calendar} como um link público",
    "You removed public link for calendar {calendar}" : "Você removeu o link público para o calendário {calendar} ",
    "{actor} shared calendar {calendar} with you" : "{actor} compartilhou o calendário  {calendar} com você",
    "You shared calendar {calendar} with {user}" : "Você compartilhou o calendário {calendar} com {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartilhou o calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} descompartilhou o calendário {calendar} com você",
    "You unshared calendar {calendar} from {user}" : "Você descompartilhou o calendário {calendar} com {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} descompartilhou o calendário {calendar} de {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} descompartilhou o calendário {calendar} deles mesmos",
    "You shared calendar {calendar} with group {group}" : "Você compartilhou o calendário {calendar} com o grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartilhou o calendário {calendar} com o grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Você descompartilhou o calendário {calendar} do grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} descompartilhou o calendário {calendar} do grupo {group}",
    "Untitled event" : "Evento sem título",
    "{actor} created event {event} in calendar {calendar}" : "{actor} criou o evento {event} no calendário {calendar}",
    "You created event {event} in calendar {calendar}" : "Você criou o evento {event} no calendário {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} excluiu o evento {event} do calendário {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Você excluiu o evento {event} do calendário {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} atualizou o evento {event} no calendário {calendar}",
    "You updated event {event} in calendar {calendar}" : "Você atualizou o evento {event} no calendário {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} moveu o evento {event} do calendario {sourceCalendar} para o calendario {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Você moveu o evento {event} do calendario {sourceCalendar} para o calendario {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} restaurou o evento {event} do calendário {calendar}",
    "You restored event {event} of calendar {calendar}" : "Você restaurou o evento {event} do calendário {calendar}",
    "Busy" : "Ocupado",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} criou tarefa {todo} na lista {calendar}",
    "You created to-do {todo} in list {calendar}" : "Você criou a tarefa {todo} na lista {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} excluiu a tarefa {todo} da lista {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Você excluiu a tarefa {todo} da lista {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} atualizou a tarefa {todo} na lista {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Você atualizou a tarefa {todo} na lista {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} resolveu a tarefa {todo} na lista {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Você resolveu a tarefa {todo} na lista {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} reabriu a tarefa {todo} na lista {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Você reabriu a tarefa {todo} na lista {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} moveu a tarefa {todo} da lista {sourceCalendar} para a lista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Você moveu a tarefa {todo} da lista {sourceCalendar} para a lista {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendário, contatos e tarefas",
    "A <strong>calendar</strong> was modified" : "Um <strong>calendário</strong> foi modificado",
    "A calendar <strong>event</strong> was modified" : "Um <strong>evento</strong> do calendário foi modificado",
    "A calendar <strong>to-do</strong> was modified" : "Um calendário <strong>tarefa</strong> foi modificado",
    "Contact birthdays" : "Aniversário dos contatos",
    "Death of %s" : "Morte de %s",
    "Untitled calendar" : "Calendário sem título",
    "Calendar:" : "Calendário:",
    "Date:" : "Data:",
    "Where:" : "Onde:",
    "Description:" : "Descrição:",
    "_%n year_::_%n years_" : ["%n ano","%n anos","%n anos"],
    "_%n month_::_%n months_" : ["%n mês","%n meses","%n meses"],
    "_%n day_::_%n days_" : ["%n dia","%n dias","%n dias"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos","%n minutos"],
    "%s (in %s)" : "%s (em %s)",
    "%s (%s ago)" : "%s (%s atrás)",
    "Calendar: %s" : "Calendário: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descrição: %s",
    "Where: %s" : "Onde: %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Cancelled: %1$s" : "Cancelado: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" foi cancelado",
    "Re: %1$s" : "Remetente: %1$s",
    "%1$s has responded to your invitation" : "%1$s respondeu ao seu convite",
    "Invitation updated: %1$s" : "Invitation updated: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s updated the event \"%2$s\"",
    "Invitation: %1$s" : "Convite: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s gostaria de convidá-lo para \"%2$s\"",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Participantes:",
    "Title:" : "Título:",
    "Time:" : "Horário:",
    "Location:" : "Localização:",
    "Link:" : "Link:",
    "Accept" : "Aceitar",
    "Decline" : "Rejeitar",
    "More options …" : "Mais opções...",
    "More options at %s" : "Mais opções em %s",
    "Contacts" : "Contatos",
    "{actor} created address book {addressbook}" : "{actor} criou o livro de endereço {addressbook}",
    "You created address book {addressbook}" : "Você criou o catálogo de endereços  {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} apagou o livro de endereços  {addressbook}",
    "You deleted address book {addressbook}" : "Você excluiu o catálogo de endereços {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} atualizou o livro de endereço {addressbook}",
    "You updated address book {addressbook}" : "Você atualizou o livro de endereço {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} compartilhou o livro de endereço {addressbook} com você",
    "You shared address book {addressbook} with {user}" : "Você compartilhou o catálogo de endereços {addressbook} com {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} compartilhou o livro de endereço {addressbook} com {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} retirou o compartilhamento do livro de endereço {addressbook} com você",
    "You unshared address book {addressbook} from {user}" : "Você retirou o compartilhamento do livro de endereço {addressbook} com {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} retirou o compartilhamento do livro de endereço {addressbook} com {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} retirou o compartilhamento do livro de endereço {addressbook} com ele mesmo",
    "You shared address book {addressbook} with group {group}" : "Você compartilhou o livro de endereço {addressbook} com o grupo {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} compartilhou o livro de endereço {addressbook} com o grupo {group}",
    "You unshared address book {addressbook} from group {group}" : "Você retirou o compartilhamento do livro de enredeços {addressbook} com o grupo {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} retirou o compartilhamento do livro de endereço {addressbook} com o grupo {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} criou o contato {card} no livro de enrereço {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Você criou o contato {card} no livro de endereço {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} excluiu o contato {card} do livro de endereço {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Você apagou o contato {card} do livro de endereços {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} updated contact {card} no livro de endereço {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Você atualizou o contato  {card} no livro de endereços  {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "O <strong>contato</strong> ou <strong>livro de endereço</strong> foi modificado",
    "File is not updatable: %1$s" : "O arquivo não é atualizável: %1$s",
    "Could not write to final file, canceled by hook" : "Não foi possível gravar no arquivo final, cancelado pelo gancho",
    "Could not write file contents" : "Não foi possível gravar o conteúdo do arquivo",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Erro ao copiar o arquivo para o local de destino (copiado: %1$s, tamanho de arquivo esperado: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Tamanho de arquivo esperado de %1$s mas lido (do cliente Nextcloud) e gravado (no armazenamento Nextcloud) %2$s. Pode ser um problema de rede no lado de envio ou um problema de gravação no armazenamento no lado do servidor.",
    "Could not rename part file to final file, canceled by hook" : "Não foi possível renomear o arquivo de parte para o arquivo final, cancelado pelo gancho",
    "Could not rename part file to final file" : "Não foi possível renomear o arquivo de parte para o arquivo final",
    "Failed to check file size: %1$s" : "Falha ao verificar o tamanho do arquivo: %1$s",
    "Could not open file" : "Não pode abrir o arquivo",
    "Encryption not ready: %1$s" : "A criptografia não está pronta: %1$s",
    "Failed to open file: %1$s" : "Falha ao abrir arquivo: %1$s",
    "Failed to unlink: %1$s" : "Falha ao desvincular: %1$s",
    "Invalid chunk name" : "Nome do bloco inválido",
    "Could not rename part file assembled from chunks" : "Não foi possível renomear parte do arquivo montado a partir de pedaços",
    "Failed to write file contents: %1$s" : "Falha ao gravar o conteúdo do arquivo:%1$s",
    "File not found: %1$s" : "Arquivo não encontrado:%1$s",
    "System is in maintenance mode." : "O sistema está em modo de manutenção",
    "Upgrade needed" : "Upgrade necessário",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Seu %s precisa estar configurado para usar HTTPS a fim de usar o CalDAV e o CardDAV com o iOS/macOS.",
    "Configures a CalDAV account" : "Configure uma conta CalDAV",
    "Configures a CardDAV account" : "Configure uma conta CardDAV",
    "Events" : "Eventos",
    "Tasks" : "Tarefas",
    "Untitled task" : "Tarefa sem título",
    "Completed on %s" : "Concluída em %s",
    "Due on %s by %s" : "Vence em %s até %s",
    "Due on %s" : "Vence em %s",
    "Migrated calendar (%1$s)" : "Calendário migrado (%1$s)",
    "Calendars including events, details and attendees" : "Calendários, incluindo eventos, detalhes e participantes",
    "Contacts and groups" : "Contatos e grupos",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Endpoint WebDAV",
    "Availability" : "Disponibilidade",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Se você configurar seu horário de trabalho, outros usuários verão quando você estiver fora do escritório quando marcarem uma reunião. ",
    "Time zone:" : "Fuso horário:",
    "to" : "para",
    "Delete slot" : "Excluir slot",
    "No working hours set" : "Sem horário de trabalho definido",
    "Add slot" : "Adicionar slot ",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado ",
    "Sunday" : "Domingo",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Defina automaticamente o status do usuário como \"Não perturbe\" fora de disponibilidade para silenciar todas as notificações.",
    "Save" : "Salvar",
    "Failed to load availability" : "Falha ao carregar a disponibilidade",
    "Saved availability" : "Disponibilidade salva",
    "Failed to save availability" : "Falha ao salvar a disponibilidade",
    "Calendar server" : "Servidor de calendário",
    "Send invitations to attendees" : "Enviar convites aos participantes",
    "Automatically generate a birthday calendar" : "Gerar um calendário de aniversários automaticamente",
    "Birthday calendars will be generated by a background job." : "Os calendários de aniversários serão gerados na retaguarda.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Portanto, eles não estarão disponíveis imediatamente após a ativação, mas depois de algum tempo.",
    "Send notifications for events" : "Enviar notificações para eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "As notificações são enviadas via trabalhos em segundo plano, portanto, elas devem ocorrer com frequência suficiente.",
    "Send reminder notifications to calendar sharees as well" : "Envie notificações de lembrete para compartilhamentos de calendário também",
    "Reminders are always sent to organizers and attendees." : "Os lembretes são sempre enviados aos organizadores e participantes.",
    "Enable notifications for events via push" : "Ativar notificações para eventos via push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale também o {calendarappstoreopen}aplicativo de calendário{linkclose} ou {calendardocopen}conecte sua área de trabalho e celular à sincronização ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Certifique-se de configurar corretamente {emailopen}o servidor de e-mail{linkclose}.",
    "There was an error updating your attendance status." : "Houve um erro ao atualizar seu status de participação.",
    "Please contact the organizer directly." : "Por favor, contate o organizador diretamente.",
    "Are you accepting the invitation?" : "Você está aceitando o convite?",
    "Tentative" : "Tentativa",
    "Your attendance was updated successfully." : "Sua presença foi atualizada com sucesso.",
    "Todos" : "Tarefas",
    "{actor} created todo {todo} in list {calendar}" : "{actor} criou a tarefa {todo} na lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Você criou a tarefa {todo} na lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} excluiu a tarefa {todo} da lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Você excluiu a tarefa {todo} da lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} atualizou a tarefa {todo} na lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Você atualizou a tarefa {todo} na lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} tarefa resolvida {todo} na lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Você terminou a tarefa  {todo} na lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabriu tarefa {todo} na lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Você reabriu a terefa {todo} na lista {calendar}",
    "A calendar <strong>todo</strong> was modified" : "Uma <strong>tarefa</strong> do calendário foi modificada",
    "Invitation canceled" : "Convite cancelado",
    "Invitation updated" : "Convite atualizado",
    "Invitation" : "Convite"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
